==> apache-camel-3.20.5-src.zip: apache-camel-3.20.5/components/camel-aws/camel-aws2-sts/src/main/java/org/apache/camel/component/aws2/sts/client/STS2ClientFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.sts.client;

import org.apache.camel.component.aws2.sts.STS2Configuration;
import org.apache.camel.component.aws2.sts.client.impl.STS2ClientIAMOptimized;
import org.apache.camel.component.aws2.sts.client.impl.STS2ClientStandardImpl;

/**
 * Factory class to return the correct type of AWS STS aws.
 */
public final class STS2ClientFactory {

    private STS2ClientFactory() {
    }

    /**
     * Return the correct aws STS client (based on remote vs local).
     *
     * @param  configuration configuration
     * @return               StsClient
     */
    public static STS2InternalClient getStsClient(STS2Configuration configuration) {
        return configuration.isUseDefaultCredentialsProvider()
                ? new STS2ClientIAMOptimized(configuration) : new STS2ClientStandardImpl(configuration);
    }
}

==> apache-camel-3.22.1-src.zip: apache-camel-3.22.1/components/camel-aws/camel-aws2-sts/src/main/java/org/apache/camel/component/aws2/sts/client/STS2ClientFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.sts.client;

import org.apache.camel.component.aws2.sts.STS2Configuration;
import org.apache.camel.component.aws2.sts.client.impl.STS2ClientIAMOptimized;
import org.apache.camel.component.aws2.sts.client.impl.STS2ClientStandardImpl;

/**
 * Factory class to return the correct type of AWS STS aws.
 */
public final class STS2ClientFactory {

    private STS2ClientFactory() {
    }

    /**
     * Return the correct aws STS client (based on remote vs local).
     * 
     * @param  configuration configuration
     * @return               StsClient
     */
    public static STS2InternalClient getStsClient(STS2Configuration configuration) {
        return Boolean.TRUE.equals(configuration.isUseDefaultCredentialsProvider())
                ? new STS2ClientIAMOptimized(configuration) : new STS2ClientStandardImpl(configuration);
    }
}
